/*
 *Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms and conditions in the IBM International Program License Agreement.
 *
 * Copyright IBM Corporation 2003, 2004. All Rights Reserved. 
 */
package superscript;

import com.rational.test.ft.object.interfaces.IWindow;

/**
 * This class provides some methods that may be useful for getting
 * around problems with native Microsoft Windows Applications.
 */
public abstract class WindowScript extends ExtensionScript 
{
	public static final String DIALOG_CLASSNAME = "#32770";
	/**
	 * Waits for the active window to be a dialog.
	 */
	protected IWindow findActiveDialog()
	{
		return (IWindow) waitForObject( 
			new IFindObject() 
			{
				public Object findObject()
				{
					IWindow dlg = getScreen().getActiveWindow();
					if (dlg != null && 
						dlg.getWindowClassName().equals(DIALOG_CLASSNAME))
					{
						return dlg;
					}
					return null;
				}
			}
		);
	}

	/**
	 * Find a control based on it's id
	 */
	protected IWindow childWindowFromId(IWindow parent, int id)
	{
		return (IWindow) waitForObject( 
			new FindChildWindowFromId(parent, id));
	}
	
	private class FindChildWindowFromId implements IFindObject
	{
		IWindow parent;
		int id;
		FindChildWindowFromId(IWindow parent, int id)
		{
			this.parent = parent;
			this.id = id;
		}
		
		public Object findObject()
		{
			IWindow[] children = parent.getChildren();
			if (children != null)
			{
				int n = children.length;
				for (int i = 0; i < n; ++i)
				{
					if (children[i].getId() == id)
						return children[i];
				}
			}
			return null;
		}
	}
	/**
	 * Clear the contents from an edit box
	 */
	protected void clearEdit(IWindow edit)
	{
		edit.click();
	 	edit.getTopParent().inputKeys("^{home}^+{end}{del}");
	}	
	
	
	/**
	 * General-purpose exception for window scripts
	 */
	public static class WindowScriptException extends RuntimeException
	{
		WindowScriptException(String s) { super(s); }
	}
	
	
}

